geochemistrypi.data\_mining.model package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geochemistrypi.data_mining.model.func

Submodules
----------

geochemistrypi.data\_mining.model.classification module
-------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.model.classification
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.model.clustering module
---------------------------------------------------

.. automodule:: geochemistrypi.data_mining.model.clustering
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.model.decomposition module
------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.model.decomposition
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.model.detection module
--------------------------------------------------

.. automodule:: geochemistrypi.data_mining.model.detection
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.model.regression module
---------------------------------------------------

.. automodule:: geochemistrypi.data_mining.model.regression
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: geochemistrypi.data_mining.model
   :members:
   :undoc-members:
   :show-inheritance:
